<?php

/***************************************************************************
 *                            lang_admin.php [Croatian]
 *                              -------------------
 *     begin                : Sat Dec 16 2000
 *     copyright            : (C) 2001 The phpBB Group
 *     email                : support@phpbb.com
 *
 *     $Id: lang_admin.php,v 1.35.2.9 2003/06/10 00:31:19 psotfx Exp $
 *
 ****************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

/***************************************************************************
 *   CONTRIBUTORS
 *   <NE brii i NE mijenjaj!>
 *   Danas e biti toplo i sunano.
 *   [Hrvatski]
 *   Prevela s engleskog na hrvatski: Anica Sean [Ancica Secan].
 *   Vrijeme: 22. travnja 2003. godine [utorak].
 *   Updateano za 2.0.5: 19. lipnja 2003. godine [etvrtak].
 *   Updateano za 2.0.11: 30. sijenja 2005. godine [nedjelja].
 *   Verzija: 3.3.3.
 *   Url: http://ancica.sunceko.net.
 *   Danas e biti toplo i sunano.
 *   Original ovog mog prijevoda moe skinuti sa www.phpbb.com.
 *   Danas e biti toplo i sunano.
 *   </NE brii i NE mijenjaj!>
 ***************************************************************************/

//
// Format is same as lang_main
//

//
// Modules, this replaces the keys used
// in the modules[][] arrays in each module file
//

$lang['General'] = 'Openito';
$lang['Users'] = 'Korisnici/e';
$lang['Groups'] = 'Grupe';
$lang['Forums'] = 'Forumi';
$lang['Styles'] = 'Stilovi';

$lang['Configuration'] = 'Konfiguracija';
$lang['Permissions'] = 'Dozvole';
$lang['Manage'] = 'Administracija';
$lang['Disallow'] = 'Nedoputena imena';
$lang['Prune'] = 'Izbrisivanje';
$lang['Mass_Email'] = 'Skupni e-mail';
$lang['Ranks'] = 'Statusi';
$lang['Smilies'] = 'Smajlii';
$lang['Ban_Management'] = 'Iskljuivanje';
$lang['Word_Censor'] = 'Cenzura rijei';
$lang['Export'] = 'Eksport';
$lang['Create_new'] = 'Kreiranje';
$lang['Add_new'] = 'Dodavanje';
$lang['Backup_DB'] = 'Backup baze';
$lang['Restore_DB'] = 'Restore baze';

//
// Index
//

$lang['Admin'] = 'Izbornik';
$lang['Not_admin'] = 'Niste ovlateni za administriranje foruma.';
$lang['Welcome_phpBB'] = 'Dobro doli na phpBB';
$lang['Admin_intro'] = 'Hvala Vam to ste izabrali phpBB kao rjeenje za Va forum.<br />Na ovu stranicu se moete vratiti klikom na <u>Index</u> link na lijevom izborniku.<br />Na poetnu stranicu foruma se moete vratiti klikom na <u>Forum</u> link na lijevom izborniku.<br />Ostali linkovi, s izbornika lijevo, Vas vode na stranice na kojima moete podesiti sve aspekte ovog foruma.';
$lang['Main_index'] = 'Forum';
$lang['Forum_stats'] = 'Statistika';
$lang['Admin_Index'] = 'Index';
$lang['Preview_forum'] = 'Prikaz foruma';

$lang['Click_return_admin_index'] = 'Kliknite %sovdje%s za povratak na Index.';

$lang['Statistic'] = 'Statistika';
$lang['Value'] = 'Vrijednost';
$lang['Number_posts'] = 'Broj postova';
$lang['Posts_per_day'] = 'Postova dnevno';
$lang['Number_topics'] = 'Broj tema';
$lang['Topics_per_day'] = 'Tema dnevno';
$lang['Number_users'] = 'Broj korisnika/ca';
$lang['Users_per_day'] = 'Korisnika/ca dnevno';
$lang['Board_started'] = 'Forum pokrenut';
$lang['Avatar_dir_size'] = 'Veliina Avatar mape';
$lang['Database_size'] = 'Veliina baze';
$lang['Gzip_compression'] ='Gzip kompresija';
$lang['Not_available'] = 'Nedostupno';

$lang['ON'] = 'DA'; // This is for GZip compression
$lang['OFF'] = 'NE'; 


//
// DB Utils
//

$lang['Database_Utilities'] = 'Alati za bazu';

$lang['Restore'] = 'Restore';
$lang['Backup'] = 'Backup';
$lang['Restore_explain'] = 'Ovdje moete izvriti potpuni povrat svih phpBB tabela iz [ranije] snimljene datoteke.<br />Ako Va server podrava tu opciju, moete uploadati gzip-kompresiranu tekst datoteku koja e automatski biti dekompresirana.<br /><b>UPOZORENJE:</b> ovime ete prepisati postojee podatke.<br />Proces moe [po]trajati podue, stoga, ostanite na ovoj stranici dok operacija ne bude zgotovljena.';
$lang['Backup_explain'] = 'Ovdje moete backupirati [napraviti kopiju] sve Vae phpBB podatke.<br />Ako imate bilo kakve dodatne tabele, u istoj bazi s phpBB, koje biste eljeli backupirati, unesite njihova imena, odvojena zarezima, u <i>Dodatne tabele</i>.<br />Ako Va server podrava tu opciju, moete koristiti gzip kompresiju kako biste smanjili veliinu datoteke prije downloadiranja.';

$lang['Backup_options'] = 'Backup opcije';
$lang['Start_backup'] = 'Zaponite Backup';
$lang['Full_backup'] = 'Potpun Backup';
$lang['Structure_backup'] = 'Strukturalni Backup';
$lang['Data_backup'] = 'Podatkovni Backup';
$lang['Additional_tables'] = 'Dodatne tabele';
$lang['Gzip_compress'] = 'Gzip kompresirana datoteka';
$lang['Select_file'] = 'Izaberite datoteku';
$lang['Start_Restore'] = 'Zaponite Restore';

$lang['Restore_success'] = 'Baza je uspjeno povraena.<br /><br />Forum bi sada trebao biti u stanju u kakvom je bio kada je napravljen Backup.';
$lang['Backup_download'] = 'Download e poeti ubrzo; priekajte dok ne pone.';
$lang['Backups_not_supported'] = 'Backup baze trenutno nije sistemski podran.';

$lang['Restore_Error_uploading'] = 'Dolo je do greke prilikom uploadiranja Backup datoteke.';
$lang['Restore_Error_filename'] = 'Dolo je do problema s imenom datoteke; probajte s alternativnom datotekom.';
$lang['Restore_Error_decompress'] = 'Nije mogue dekompresirati Gzip datoteku.<br />Pokuajte s uploadom Plain Text verzije.';
$lang['Restore_Error_no_file'] = 'Nijedna datoteka nije uploadirana.';

//
// Auth pages
//

$lang['Select_a_User'] = 'Izaberite korisnika/cu';
$lang['Select_a_Group'] = 'Izaberite grupu';
$lang['Select_a_Forum'] = 'Izaberite forum';
$lang['Auth_Control_User'] = 'Kontrola dozvola korisnika/ca';
$lang['Auth_Control_Group'] = 'Kontrola dozvola grupa';
$lang['Auth_Control_Forum'] = 'Kontrola dozvola foruma';
$lang['Look_up_User'] = 'Potraite korisnika/cu';
$lang['Look_up_Group'] = 'Potraite grupu';
$lang['Look_up_Forum'] = 'Potraite forum';

$lang['Group_auth_explain'] = 'Ovdje moete definirati dozvole i moderatorski status svake Korisnike grupe.<br />Obratite panju na individualne postavke koje ste dodijelili korisniku/ci - ako su drugaije od postavki koje ste dodijelili Korisnikoj grupi korisnik/ca e i dalje moi koristiti dozvole koje ste mu/joj individualno dodijelili [ukoliko se dogodi da postavke ne budu identine - bit ete obavijeteni o tome].';
$lang['User_auth_explain'] = 'Ovdje moete definirati dozvole i moderatorski status svakog/e korisnika/ce.<br />Obratite panju na postavke koje ste dodijelili Korisnikoj grupi [ako je koje korisnik/ca lan/ica] - ako su drugaije od postavki koje ste dodijelili individualno korisniku/ci on/a e i dalje moi koristiti dozvole koje ste dodijelili Korisnikoj grupi [ukoliko se dogodi da postavke ne budu identine - bit ete obavijeteni o tome].';
$lang['Forum_auth_explain'] = 'Ovdje moete [jednostavnim ili naprednim sueljem] definirati mogunosti pristupa forumima.<br />Obratite panju na to da se promjenom dozvola pristupa odreuje i koji/e korisnici/e e imati prava koritenja/upravljanja forumima.';

$lang['Simple_mode'] = 'Jednostavno suelje';
$lang['Advanced_mode'] = 'Napredno suelje';
$lang['Moderator_status'] = 'Moderatorski status';

$lang['Allowed_Access'] = 'Dozvoljen pristup';
$lang['Disallowed_Access'] = 'Nedozvoljen pristup';
$lang['Is_Moderator'] = 'Je Moderator/ica';
$lang['Not_Moderator'] = 'Nije Moderator/ica';

$lang['Conflict_warning'] = 'Autorizacijski konflikt';
$lang['Conflict_access_userauth'] = 'Korisnik/ca jo uvijek ima pristup forumu na konto prava Korisnike grupe koje je lan/ica.<br />Ukoliko mu/joj elite uskratiti pravo pristupa forumu: ili promijenite prava Korisnike grupe ili ga/ju izbriite iz lanstva u toj Korisnikoj grupi. Prava Korisnike grupe vidljiva su ispod.';
$lang['Conflict_mod_userauth'] = 'Korisnik/ca jo uvijek ima moderatorska prava na forumu na konto prava Korisnike grupe koje je lan/ica.<br />Ukoliko mu/joj elite uskratiti pravo pristupa forumu: ili promijenite prava Korisnike grupe ili ga/ju izbriite iz lanstva u toj Korisnikoj grupi. Prava Korisnike grupe vidljiva su ispod.';

$lang['Conflict_access_groupauth'] = 'Korisnik(ci)/ca(e) jo uvijek ima/ju pristup forumu na konto individualnih prava.<br />Ukoliko mu/joj/im elite uskratiti pravo pristupa forumu: promijenite mu/joj/im individualna prava. Korisnika prava vidljiva su ispod.';
$lang['Conflict_mod_groupauth'] = 'Korisnik(ci)/ca(e) jo uvijek moderatorska prava na forumu na konto individualnih prava.<br />Ukoliko mu/joj/im elite uskratiti pravo pristupa forumu: promijenite mu/joj/im individualna prava. Korisnika prava vidljiva su ispod.';

$lang['Public'] = 'Javan/na';
$lang['Private'] = 'Privatan/na';
$lang['Registered'] = 'Registriran/a/e/i';
$lang['Administrators'] = 'Administratori/ce';
$lang['Hidden'] = 'Skriven/a';

// These are displayed in the drop down boxes for advanced
// mode forum auth, try and keep them short!

$lang['Forum_ALL'] = 'SVI';
$lang['Forum_REG'] = 'REG';
$lang['Forum_PRIVATE'] = 'PRI';
$lang['Forum_MOD'] = 'MOD';
$lang['Forum_ADMIN'] = 'ADM';

$lang['View'] = 'Pogledajte';
$lang['Read'] = 'Proitajte';
$lang['Post'] = 'Postajte';
$lang['Reply'] = 'Odgovorite';
$lang['Edit'] = 'Uredite';
$lang['Delete'] = 'Izbriite';
$lang['Sticky'] = 'Vano';
$lang['Announce'] = 'Obavijesti'; 
$lang['Vote'] = 'Glasujte';
$lang['Pollcreate'] = 'Kreiranje anketa';

$lang['Permissions'] = 'Dozvole';
$lang['Simple_Permission'] = 'Jednostavne dozvole';

$lang['User_Level'] = 'Korisniki status'; 
$lang['Auth_User'] = 'Korisnik/ca';
$lang['Auth_Admin'] = 'Administrator/ica';
$lang['Group_memberships'] = 'lanstvo Korisnikih grupa';
$lang['Usergroup_members'] = 'lanstvo ove Korisnike grupe';

$lang['Forum_auth_updated'] = 'Dozvole foruma aurirane.';
$lang['User_auth_updated'] = 'Korisnike dozvole aurirane.';
$lang['Group_auth_updated'] = 'Dozvole Korisnike grupe aurirane.';

$lang['Auth_updated'] = 'Dozvole su aurirane.';
$lang['Click_return_userauth'] = 'Kliknite %sovdje%s za povratak na korisnike dozvole.';
$lang['Click_return_groupauth'] = 'Kliknite %sovdje%s za povratak na dozvole Korisnikih grupa.';
$lang['Click_return_forumauth'] = 'Kliknite %sovdje%s za povratak na dozvole foruma.';

//
// Banning
//

$lang['Ban_control'] = 'Iskljuivanje';
$lang['Ban_explain'] = 'Ovdje moete iskljuiti [zabraniti pristup] korisnika/cu s foruma.<br />Moete iskljuiti korisnika/cu, IP adresu pristupa, adresu pruatelja usluga...<br />Ovime se iskljuenoj osobi moe zabraniti pristup ak i na Poetnu stranicu foruma.<br />Da biste sprijeili iskljuenu osobu da se ponovo registrira, moete iskljuiti i odreenu e-mail adresu [iskljuivanje samo e-mail adrese nee sprijeiti osobu da se loginira i posta].';
$lang['Ban_explain_warn'] = 'Unoenje opsega IP adresa rezultira time da e sve IP adrese, od poetne do zadnje, biti dodane na listu iskljuenih [blokiranih] IP adresa.<br />Pokuajte minimizirati broj dodatnih IP adresa unoenjem zvjezdica (*) gdje god je to mogue.<br />Ako stvarno morate blokirati opseg adresa, pazite da bude to manji.';

$lang['Select_username'] = 'Izaberite korisniko ime';
$lang['Select_ip'] = 'Izaberite IP adresu';
$lang['Select_email'] = 'Izaberite e-mail adresu';

$lang['Ban_username'] = 'Iskljuite korisnika(e)/cu(e)';
$lang['Ban_username_explain'] = 'Moete iskljuiti vie korisnika/ca odjednom koristei kombinaciju mia i tipkovnice za Vae raunalo i preglednik.';

$lang['Ban_IP'] = 'Iskljuite IP adresu(e)/adresu(e) pruatelja usluga';
$lang['IP_hostname'] = 'IP adrese/adrese pruatelja usluga';
$lang['Ban_IP_explain'] = 'Da biste specificirali vie razliitih IP adresa/adresa pruatelja usluga - odvojite ih zarezima.<br />Da biste specificirali opseg IP adresa - odvojite poetak i kraj crticom (-); moete koristiti i zvjezdice (*).';

$lang['Ban_email'] = 'Iskljuite e-mail adresu/e';
$lang['Ban_email_explain'] = 'Da biste specificirali vie razliitih e-mail adresa - odvojite ih zarezima; moete koristiti i zvjezdice (*) [npr. *@hotmail.com].';

$lang['Unban_username'] = 'Odiskljuite korisnika(e)/cu(e)';
$lang['Unban_username_explain'] = 'Moete odiskljuiti vie korisnika/ca odjednom koristei kombinaciju mia i tipkovnice za Vae raunalo i preglednik.';

$lang['Unban_IP'] = 'Odiskljuite IP adresu/e';
$lang['Unban_IP_explain'] = 'Moete odiskljuiti vie IP adresa odjednom koristei kombinaciju mia i tipkovnice za Vae raunalo i preglednik.';

$lang['Unban_email'] = 'Odiskljuite e-mail adresu/e';
$lang['Unban_email_explain'] = 'Moete odiskljuiti vie e-mail adresa odjednom koristei kombinaciju mia i tipkovnice za Vae raunalo i preglednik.';

$lang['No_banned_users'] = 'Nema iskljuenih korisnika/ca';
$lang['No_banned_ip'] = 'Nema iskljuenih IP adresa';
$lang['No_banned_email'] = 'Nema iskljuenih e-mail adresa';

$lang['Ban_update_sucessful'] = 'Iskljuna lista je aurirana.';
$lang['Click_return_banadmin'] = 'Kliknite %sovdje%s za povratak na Iskljuivanje.';

//
// Configuration
//

$lang['General_Config'] = 'Opa konfiguracija';
$lang['Config_explain'] = 'Donja forma Vam omoguava podeavanje svih opih postavki foruma.<br />Za konfiguriranje korisnika(ca)/foruma koristite linkove na izborniku lijevo.';

$lang['Click_return_config'] = 'Kliknite %sovdje%s za povratak na Opu konfiguraciju.';

$lang['General_settings'] = 'Ope postavke foruma';
$lang['Server_name'] = 'Naziv domene';
$lang['Server_name_explain'] = '<i>Naziv domene pokretanja foruma.</i>';
$lang['Script_path'] = 'Putanja skripta';
$lang['Script_path_explain'] = '<i>Putanja smjetaja phpBB-a u odnosu na naziv domene.</i>';
$lang['Server_port'] = 'Port servera';
$lang['Server_port_explain'] = '<i>Port na kojemu radi Va server, obino 80 [promijenite samo ako je drugi].</i>';
$lang['Site_name'] = 'Naziv stranica';
$lang['Site_desc'] = 'Opis stranica';
$lang['Board_disable'] = 'Onemoguite forum';
$lang['Board_disable_explain'] = '<i>Ovo e forum uiniti nedostupnim korisnicima/ama.<br />Nemojte se logoutirati [odjaviti] ako disableirate [onemoguite] forum jer se vie neete moi loginirati.</i>';
$lang['Acct_activation'] = 'Omoguite aktivaciju korisnikog rauna';
$lang['Acc_None'] = '/'; // These three entries are the type of activation
$lang['Acc_User'] = 'Korisnik/ca';
$lang['Acc_Admin'] = 'Administrator/ica';

$lang['Abilities_settings'] = 'Osnovne korisnike i foruma postavke';
$lang['Max_poll_options'] = 'Max broj odgovora u anketama';
$lang['Flood_Interval'] = 'Interval ekanja';
$lang['Flood_Interval_explain'] = '<i>Broj sekundi koje moraju proi izmeu postanja dvaju postova korisnika/ce.</i>'; 
$lang['Board_email_form'] = 'Forumski e-mail';
$lang['Board_email_form_explain'] = '<i>Mogunost korisnikog meusobnog slanja e-mailova putem forme foruma.</i>';
$lang['Topics_per_page'] = 'Tema po stranici';
$lang['Posts_per_page'] = 'Postova po stranici';
$lang['Hot_threshold'] = 'Popularni postovi';
$lang['Default_style'] = 'Defaultni stil';
$lang['Override_style'] = 'Onemoguen korisniki stil';
$lang['Override_style_explain'] = '<i>Zamjenjuje korisniki stil defaultnim.</i>';
$lang['Default_language'] = 'Defaultni jezik';
$lang['Date_format'] = 'Format datuma';
$lang['System_timezone'] = 'Vremenska zona';
$lang['Enable_gzip'] = 'Omoguite GZip kompresiju';
$lang['Enable_prune'] = 'Omoguite izbrisivanje foruma';
$lang['Allow_HTML'] = 'Dozvolite HTML';
$lang['Allow_BBCode'] = 'Dozvolite BBCode';
$lang['Allowed_tags'] = 'Dozvolite HTML tagove';
$lang['Allowed_tags_explain'] = '<i>Tagove odvojite zarezima.</i>';
$lang['Allow_smilies'] = 'Dozvolite Smajlie';
$lang['Smilies_path'] = 'Putanja spremanja Smajlia';
$lang['Smilies_path_explain'] = '<i>Putanja smjetaja [mape] spremanja Smajlia u odnosu na phpBB [npr. images/smiles].</i>';
$lang['Allow_sig'] = 'Dozvolite potpise';
$lang['Max_sig_length'] = 'Max duina potpisa';
$lang['Max_sig_length_explain'] = '<i>Max broj znakova u potpisu korisnika/ce.</i>';
$lang['Allow_name_change'] = 'Dozvolite promjene korisnikih imena';

$lang['Avatar_settings'] = 'Postavke Avatara';
$lang['Allow_local'] = 'Omoguite galeriju Avatara';
$lang['Allow_remote'] = 'Omoguite linkane Avatare';
$lang['Allow_remote_explain'] = '<i>Avatari koji su smjeteni na drugim i pozivaju se s tih stranica.</i>';
$lang['Allow_upload'] = 'Omoguite uploadanje Avatara';
$lang['Max_filesize'] = 'Max veliina Avatara';
$lang['Max_filesize_explain'] = '<i>Za uploadane Avatare.</i>';
$lang['Max_avatar_size'] = 'Max dimenzije Avatara';
$lang['Max_avatar_size_explain'] = '<i>Visina x irina u px.</i>';
$lang['Avatar_storage_path'] = 'Putanja spremanja Avatara';
$lang['Avatar_storage_path_explain'] = '<i>Putanja smjetaja [mape] spremanja Avatara u odnosu na phpBB [npr. images/avatars].</i>';
$lang['Avatar_gallery_path'] = 'Putanja galerije Avatara';
$lang['Avatar_gallery_path_explain'] = '<i>Putanja galerije Avatara u odnosu na phpBB [npr. images/avatars/gallery].</i>';

$lang['COPPA_settings'] = 'COPPA postavke';
$lang['COPPA_fax'] = 'COPPA broj faksa';
$lang['COPPA_mail'] = 'COPPA potanska adresa';
$lang['COPPA_mail_explain'] = '<i>Potanska adresa na koju roditelji/staratelji mogu poslati COPPA registracijski formular.</i>';

$lang['Email_settings'] = 'E-mail postavke';
$lang['Admin_email'] = 'E-mail adresa Administratora/ice';
$lang['Email_sig'] = 'E-mail potpis';
$lang['Email_sig_explain'] = '<i>Ovaj potpis e biti dodan svakoj e-mail poruci koja bude poslana u ime foruma.</i>';
$lang['Use_SMTP'] = 'Koritenje SMTP servera za e-mail';
$lang['Use_SMTP_explain'] = '<i>Izaberite <i>Da</i> ukoliko elite/morate slati e-mail poruke putem imenovanog servera umjesto lokalne e-mail funkcije.</i>';
$lang['SMTP_server'] = 'Adresa SMTP servera';
$lang['SMTP_username'] = 'SMTP korisniko ime';
$lang['SMTP_username_explain'] = '<i>Korisniko ime unesite samo ako to Va SMTP server zahtjeva.</i>';
$lang['SMTP_password'] = 'SMTP zaporka';
$lang['SMTP_password_explain'] = '<i>Zaporku unesite samo ako to Va SMTP server zahtjeva.</i>';

$lang['Disable_privmsg'] = 'Privatne poruke';
$lang['Inbox_limits'] = 'Max poruka u Inboxu';
$lang['Sentbox_limits'] = 'Max poruka u Sentboxu';
$lang['Savebox_limits'] = 'Max poruka u Saveboxu';

$lang['Cookie_settings'] = 'Cookie postavke'; 
$lang['Cookie_settings_explain'] = '<i>Ovi detalji definiraju kako se Cookies [Kolaii] alju preglednicima Vaih korisnika/ca. <br /> Najee su defaultne vrijednosti postavki Kolaia dostatne, no, ako ih morate mijenjati - pazite to radite jer nepravilne postavke mogu dovesti do nemogunosti loginiranja.</i>';
$lang['Cookie_domain'] = 'Domena Kolaia';
$lang['Cookie_name'] = 'Naziv Kolaia';
$lang['Cookie_path'] = 'Putanja Kolaia';
$lang['Cookie_secure'] = 'Sigurnost Kolaia';
$lang['Cookie_secure_explain'] = '<i>Ako Va server radi preko SSL-a - omoguite ovu opciju; u suprotnom ju onemoguite.</i>';
$lang['Session_length'] = 'Vremensko trajanje [sec]';

// Visual Confirmation

$lang['Visual_confirm'] = 'Vizualna potvrda';
$lang['Visual_confirm_explain'] = 'Zahtijeva unos koda, definiranog slikom, kod Registracije.';

//
// Forum Management
//

$lang['Forum_admin'] = 'Administracija foruma';
$lang['Forum_admin_explain'] = 'Ovdje moete dodavati, izbrisati, ureivati, mijenjati redoslijed, te resinkronizirati kategorije/forume.';
$lang['Edit_forum'] = 'Uredite forum';
$lang['Create_forum'] = 'Kreirajte novi forum';
$lang['Create_category'] = 'Kreirajte novu kategoriju';
$lang['Remove'] = 'Uklonite';
$lang['Action'] = 'Akcija';
$lang['Update_order'] = 'Updateajte redoslijed';
$lang['Config_updated'] = 'Konfiguracija foruma je uspjeno updateana.';
$lang['Edit'] = 'Uredite';
$lang['Delete'] = 'Izbriite';
$lang['Move_up'] = 'Gore';
$lang['Move_down'] = 'Dolje';
$lang['Resync'] = 'ReSin';
$lang['No_mode'] = 'Nije podeen mod';
$lang['Forum_edit_delete_explain'] = 'Donja forma Vam omoguava podeavanje svih opih postavki foruma.<br />Za konfiguriranje korisnika(ca)/foruma koristite linkove na izborniku lijevo.';

$lang['Move_contents'] = 'Premjestite kompletan sadraj';
$lang['Forum_delete'] = 'Izbriite forum';
$lang['Forum_delete_explain'] = 'Donja forma Vam omoguava da izbriete forum(e)/kategoriju(e), te da odluite kamo elite premjestiti sadraj.';

$lang['Status_locked'] = 'Zakljuano';
$lang['Status_unlocked'] = 'Otkljuano';
$lang['Forum_settings'] = 'Ope postavke foruma';
$lang['Forum_name'] = 'Naziv foruma';
$lang['Forum_desc'] = 'Opis';
$lang['Forum_status'] = 'Status';
$lang['Forum_pruning'] = 'Auto-izbrisivanje';

$lang['prune_freq'] = 'Provjeri starost tema svakih';
$lang['prune_days'] = 'Ukloni teme u kojima nije bilo postanja';
$lang['Set_prune_data'] = 'Upalili ste opciju auto-izbrisivanja foruma ali niste podesili frekvenciju ili broj dana za izbrisivanje.<br />Vratite se i podesite [to].';

$lang['Move_and_Delete'] = 'Premjestite i izbriite';

$lang['Delete_all_posts'] = 'Izbriite sve postove';
$lang['Nowhere_to_move'] = 'Nema lokacije za premjetanje';

$lang['Edit_Category'] = 'Uredite kategoriju';
$lang['Edit_Category_explain'] = 'Ovom formom moete promijeniti naziv kategorije.';

$lang['Forums_updated'] = 'Informacije o forumu/ima i kategoriji/ama su uspjeno updateane.';

$lang['Must_delete_forums'] = 'Morate izbrisati sve forume da biste mogli izbrisati ovu kategoriju.';

$lang['Click_return_forumadmin'] = 'Kliknite %sovdje%s za povratak na Administraciju foruma.';

//
// Smiley Management
//

$lang['smiley_title'] = 'Administracija Smajlia';
$lang['smile_desc'] = 'Ovdje moete dodavati, uklanjati i editirati Smajlie koje korisnici/e mogu dodavati u svoje postove/privatne poruke.';

$lang['smiley_config'] = 'Konfiguracija Smajlia';
$lang['smiley_code'] = 'Kod Smajlia';
$lang['smiley_url'] = 'Datoteka Smajlia';
$lang['smiley_emot'] = 'Emocija Smajlia';
$lang['smile_add'] = 'Dodajte Smajlia';
$lang['Smile'] = 'Smajli';
$lang['Emotion'] = 'Emocija';

$lang['Select_pak'] = 'Izaberite paket (.pak) datoteku';
$lang['replace_existing'] = 'Zamijenite Smajlia';
$lang['keep_existing'] = 'Zadrite Smajlia';
$lang['smiley_import_inst'] = 'Odzipajte paket Smajlia i uploadajte sve datoteke u odgovarajuu mapu Smajlia za Vau instalaciju, te izaberite tonu informaciju u ovoj formi da biste ubacili paket Smajlia.';
$lang['smiley_import'] = 'Umetanje paketa Smajlia';
$lang['choose_smile_pak'] = 'Izaberite paket .pak datoteku Smajlia';
$lang['import'] = 'Importirajte Smajlie';
$lang['smile_conflicts'] = 'to bi trebalo napraviti u sluaju konflikata';
$lang['del_existing_smileys'] = 'Izbriite postojee Smajlie prije importiranja';
$lang['import_smile_pack'] = 'Importirajte paket Smajlia';
$lang['export_smile_pack'] = 'Kreirajte paket Smajlia';
$lang['export_smiles'] = 'Da biste kreirali paket Smajlia od trenutno instaliranih Smajlia, kliknite %sovdje%s kako biste downloadirali smiles.pak datoteku.<br />Nazovite adekvatno ovu datoteku pazei pri tome da sauvate .pak ekstenziju.<br />Zatim kreirajte zip datoteku koja sadri sve Vae Smajlie plus ovu .pak konfiguracijsku datoteku.';

$lang['smiley_add_success'] = 'Smajli je uspjeno dodan.';
$lang['smiley_edit_success'] = 'Smajli je uspjeno updateiran.';
$lang['smiley_import_success'] = 'Paket Smajlia je uspjeno importiran.';
$lang['smiley_del_success'] = 'Smajli je uspjeno uklonjen.';
$lang['Click_return_smileadmin'] = 'Kliknite %sovdje%s za povratak na Administraciju Smajlia.';

//
// User Management
//

$lang['User_admin'] = 'Administracija korisnika/ca';
$lang['User_admin_explain'] = 'Ovdje moete promijeniti odreene postavke i informacije korisnika/ca.<br />Za modificiranje dozvola korisnika/ca koristite sistem dozvola za korisnike/ce i Korisnike grupe.';

$lang['Look_up_user'] = 'Pronaite korisnika/cu';

$lang['Admin_user_fail'] = 'Nije bilo mogue updateati korisniki profil.';
$lang['Admin_user_updated'] = 'Korisniki profil je uspjeno updatean.';
$lang['Click_return_useradmin'] = 'Kliknite %sovdje%s za povratak na Administraciju korisnika/ca.';

$lang['User_delete'] = 'Izbrisivanje korisnika/ce';
$lang['User_delete_explain'] = '<i>Oznaite kuicu ukoliko elite izbrisati korisnika/cu; ova operacija ne moe biti ponitena.</i>';
$lang['User_deleted'] = 'Korisnik/ca je uspjeno izbrisan/a.';

$lang['User_status'] = 'Korisnik/ca je aktivan/na';
$lang['User_allowpm'] = 'Moe slati privatne poruke';
$lang['User_allowavatar'] = 'Moe koristiti Avatara';

$lang['Admin_avatar_explain'] = 'Ovdje moete vidjeti/izbrisati Avatara korisnika/ce.';

$lang['User_special'] = 'Posebna polja samo za administratore/ice';
$lang['User_special_explain'] = 'Ova polja ne mogu modificirati korisnici/e.<br />Ovdje moete podesiti njihov status i druge opcije kojima korisnici/e nemaju pristup.';

//
// Group Management
//

$lang['Group_administration'] = 'Administracija Korisnikih grupa';
$lang['Group_admin_explain'] = 'Ovdje moete administrirati Korisnike grupe.<br />Moete kreirati nove, te ureivati/izbrisati postojee Korisnike grupe.<br />Moete odreivati moderatore/ice, status kao i nazive i opise Korisnikih grupa.';
$lang['Error_updating_groups'] = 'Dolo je do greke prilikom updateanja Korisnike grupe.';
$lang['Updated_group'] = 'Korisnika grupa je uspjeno updateana.';
$lang['Added_new_group'] = 'Korisnika grupa je uspjeno kreirana.';
$lang['Deleted_group'] = 'Korisnika grupa je uspjeno izbrisana.';
$lang['New_group'] = 'Kreirajte novu Korisniku grupu';
$lang['Edit_group'] = 'Editirajte Korisniku grupu';
$lang['group_name'] = 'Naziv';
$lang['group_description'] = 'Opis';
$lang['group_moderator'] = 'Moderator/ica';
$lang['group_status'] = 'Status';
$lang['group_open'] = 'Otvorena';
$lang['group_closed'] = 'Zatvorena';
$lang['group_hidden'] = 'Skrivena';
$lang['group_delete'] = 'elite [li] izbrisati ovu Korisniku grupu?';
$lang['group_delete_check'] = 'Da';
$lang['submit_group_changes'] = 'Poaljite promjene';
$lang['reset_group_changes'] = 'Izbriite promjene';
$lang['No_group_name'] = 'Morate specificirati naziv Korisnike grupe.';
$lang['No_group_moderator'] = 'Morate specificirati moderatora/icu Korisnike grupe.';
$lang['No_group_mode'] = 'Morate specificirati mod Korisnike grupe, otvorena ili zatvorena.';
$lang['No_group_action'] = 'Nije specificirana akcija.';
$lang['delete_group_moderator'] = 'elite [li] izbrisati trenutnog/u moderatora/icu ove Korisnike grupe?';
$lang['delete_moderator_explain'] = '<i>Ukoliko mijenjate moderatora/icu Korisnike grupe, oznaite ovu kuicu kako biste izbrisali trenutnog moderatora/icu [ukoliko ne oznaite kuicu, trenutni moderator/ica e postati regularan lan Korisnike grupe].</i>';
$lang['Click_return_groupsadmin'] = 'Kliknite %sovdje%s za povratak na Administraciju Korisnikih grupa.';
$lang['Select_group'] = 'Izaberite Korisniku grupu';
$lang['Look_up_group'] = 'Potraite Korisniku grupu';

//
// Prune Administration
//

$lang['Forum_Prune'] = 'Administracija izbrisivanja foruma';
$lang['Forum_Prune_explain'] = 'Ovdje moete izbrisati svaku temu u kojoj nije bilo novih postova u rasponu dana kojeg odredite.<br />Ukoliko ne odredite broj dana - sve teme e biti izbrisane.<br />Samo aktualne ankete [one koje jo traju] i Obavijesti nee biti izbrisane [njih ete morati izbrisati runo].';
$lang['Do_Prune'] = 'Pokrenite izbrisivanje';
$lang['All_Forums'] = 'Svi forumi';
$lang['Prune_topics_not_posted'] = 'Izbriite teme u kojima nije bilo novih postova dana';
$lang['Topics_pruned'] = 'Izbrisane teme';
$lang['Posts_pruned'] = 'Izbrisani postovi';
$lang['Prune_success'] = 'Izbrisivanje foruma je uspjeno obavljeno.';

//
// Word censor
//

$lang['Words_title'] = 'Administracija cenzure rijei';
$lang['Words_explain'] = 'Ovdje moete dodavati, ureivati i izbrisati rijei koje e automatski biti cenzurirane na forumu. <br />Automatski e biti onemogueno i registriranje pod korisnikim imenom koje sadri cenzuriranu rije.<br />Moete se koristiti i zvjezdicama (*) [npr.: *test* e obuhvatiti sve rijei koje u sebi sadre rije test; test* sve koje poinju sa test; *test sve koje zavravaju sa test].';
$lang['Word'] = 'Rije';
$lang['Edit_word_censor'] = 'Uredite';
$lang['Replacement'] = 'Zamjena';
$lang['Add_new_word'] = 'Dodajte novu rije';
$lang['Update_word'] = 'Updateajte';

$lang['Must_enter_word'] = 'Morate unijeti i rije i zamjenu za nju.';
$lang['No_word_selected'] = 'Niste oznaili rije koju elite urediti.';

$lang['Word_updated'] = 'Rije je uspjeno updateana.';
$lang['Word_added'] = 'Rije je uspjeno dodana.';
$lang['Word_removed'] = 'Rije je uspjeno izbrisana.';

$lang['Click_return_wordadmin'] = 'Kliknite %sovdje%s za povratak na Administraciju cenzure rijei.';

//
// Mass Email
//

$lang['Mass_email_explain'] = 'Ovdje moete poslati e-mail svim korisnicima/ama foruma odnosno lanovima/icama Korisnikih grupa.<br />E-mail e otii s e-mail adrese administratora/ice foruma; primatelji/ce e biti navedeni/e u BCC [Na znanje] odjeljku.<br />Ukoliko je primatelja/ica puno, moda e slanje e-maila potrajati neko vrijeme - bit ete obavijeteni kada e-mail bude poslan.';
$lang['Compose'] = 'Compose'; 

$lang['Recipients'] = 'Primatelji/ce'; 
$lang['All_users'] = 'Kompletno lanstvo';

$lang['Email_successfull'] = 'Vaa poruka je poslana.';
$lang['Click_return_massemail'] = 'Kliknite %sovdje%s za povratak na formu Skupnog e-maila.';

//
// Ranks admin
//

$lang['Ranks_title'] = 'Administracija statusa';
$lang['Ranks_explain'] = 'Ovdje moete dodavati, ureivati, pregledavati i izbrisati statuse.<br />Moete kreirati proizvoljne statuse koji mogu biti primijenjeni na korisnike/ce preko Administracije korisnika/ca.';

$lang['Add_new_rank'] = 'Dodajte novi status';

$lang['Rank_title'] = 'Status';
$lang['Rank_special'] = 'Specijalni status';
$lang['Rank_minimum'] = 'Min postova';
$lang['Rank_maximum'] = 'Max postova';
$lang['Rank_image'] = 'Slika statusa [u odnosu na phpBB]';
$lang['Rank_image_explain'] = '<i>Ova sliica e se vidjeti ispod korisnikog imena kod pregledavanja postova.</i>';

$lang['Must_select_rank'] = 'Morate izabrati status.';
$lang['No_assigned_rank'] = 'Nije dodijeljen specijalan status';

$lang['Rank_updated'] = 'Status je uspjeno updatean.';
$lang['Rank_added'] = 'Status je uspjeno dodan.';
$lang['Rank_removed'] = 'Status je uspjeno izbrisan.';
$lang['No_update_ranks'] = 'Status je uspjeno izbrisan.<br />Korisniki rauni koju su bili oznaeni ovim statusom nisu updateani; to ete morati napraviti runo.';

$lang['Click_return_rankadmin'] = 'Kliknite %sovdje%s za povratak na Administraciju statusa.';

//
// Disallow Username Admin
//

$lang['Disallow_control'] = 'Administracija nedoputenih korisnikih imena';
$lang['Disallow_explain'] = 'Ovdje moete dodavati/izbrisati korisnika imena pod kojima se nitko nee moi registrirati.<br />Moete koristiti i zvjezdice (*).<br />Naravno, neete moi dodati niti jedno korisniko ime koje je ve registrirano [ukoliko to elite - morate prvo obrisati postojee korisniko ime].';

$lang['Delete_disallow'] = 'Izbriite';
$lang['Delete_disallow_title'] = 'Izbriite nedoputeno korisniko ime';
$lang['Delete_disallow_explain'] = 'Korisniko ime moete izbrisati tako da ga izaberete s liste i kliknete na gumb Izbriite.';

$lang['Add_disallow'] = 'Dodajte';
$lang['Add_disallow_title'] = 'Dodajte nedoputeno korisniko ime';
$lang['Add_disallow_explain'] = 'Moete koristiti i zvjezdice (*) - koje zamjenjuju bilo koji znak.';

$lang['No_disallowed'] = 'Nema nedoputenih korisnikih imena';

$lang['Disallowed_deleted'] = 'Nedoputeno korisniko ime je uspjeno izbrisano.';
$lang['Disallow_successful'] = 'Nedoputeno korisniko ime je uspjeno dodano.';
$lang['Disallowed_already'] = 'Ime koje ste unijeli ne moe biti nedoputeno.<br />Ili ve postoji na listi, ili postoji na listi cenzuriranih rijei ili postoji takvo korisniko ime.';

$lang['Click_return_disallowadmin'] = 'Kliknite %sovdje%s za povratak na Administraciju nedoputenih korisnikih imena.';

//
// Styles Admin
//

$lang['Styles_admin'] = 'Administracija stilova';
$lang['Styles_explain'] = 'Ovdje moete dodavati, ureivati i izbrisati stilove [teme i predloke].';
$lang['Styles_addnew_explain'] = 'Sljedea lista sadri sve teme koje su dostupne za predloke koje imate.<br />Stavke liste nisu instalirane u phpBB bazu.<br />Da biste instalirali temu, kliknite na gumb Instalirajte.';

$lang['Select_template'] = 'Izaberite predloak';

$lang['Style'] = 'Stil';
$lang['Template'] = 'Predloak';
$lang['Install'] = 'Instalirajte';
$lang['Download'] = 'Downloadirajte';

$lang['Edit_theme'] = 'Uredite temu';
$lang['Edit_theme_explain'] = 'Donjom formom moete urediti postavke izabrane teme.';

$lang['Create_theme'] = 'Kreirajte temu';
$lang['Create_theme_explain'] = 'Donjom formom moete kreirati novu temu za izabrani predloak.<br />Kod unoenja boja [za koje koristite heksadecimalni oblik] nemojte unositi znak ljestve (#) [npr.: CCCCCC je pravilno; #CCCCCC nije].';

$lang['Export_themes'] = 'Eksportirajte teme';
$lang['Export_explain'] = 'Ovdje moete eksportirati podatke teme za izabrani predloak.<br />Izaberite predloak sa donje liste i skripta e kreirati konfiguracijsku datoteku teme te ju pokuati spremiti u izabranu mapu predloaka.<br />Ukoliko ju nee moi spremiti, predloit e Vam da ju downloadirate.<br />Da bi skripta mogla spremiti datoteku, morate dati pravo pristupa webserveru za izabranu mapu predloaka.<br />Za vie informacija o ovome, pogledajte phpBB 2 vodi.';

$lang['Theme_installed'] = 'Tema je uspjeno instalirana.';
$lang['Style_removed'] = 'Izabrani stil je izbrisan iz baze.<br />Da biste stil potpuno uklonili iz sistema morate izbrisati odgovarajui stil iz mape predloaka.';
$lang['Theme_info_saved'] = 'Informacije o temi za izabrani predloak su spremljene.<br />Sada biste trebali vratiti dozvole za theme_info.cfg [ako je mogue i za izabranu mapu predloaka] u read-only [samo za itanje].';
$lang['Theme_updated'] = 'Tema je uspjeno updateana.<br />Sada biste trebali eksportirati nove postavke teme.';
$lang['Theme_created'] = 'Tema je kreirana.<br />Sada biste trebali eksportirati temu u konfiguracijsku datoteku teme zbog backupa ili uporabe negdje drugdje.';

$lang['Confirm_delete_style'] = 'Jeste li sigurni da elite izbrisati ovaj stil?';

$lang['Download_theme_cfg'] = 'Nije bilo mogue napisati konfiguracijsku datoteku teme.<br />Kliknite na donji gumb da biste downloadirali ovu datoteku preglednikom.<br />Kada ju downloadirate, moete ju transferirati u mapu predloaka.<br />Tada moete spakirati datoteke za distribuciju ili uporabe negdje drugdje.';
$lang['No_themes'] = 'Predloak kojeg ste izabrali nema tema vezanih uz sebe.<br />Da biste kreirali novu temu, kliknite na link lijevo za kreiranje nove teme.';
$lang['No_template_dir'] = 'Nije bilo mogue otvoriti mapu predloaka.<br />Moda je neitljiva webserveru ili ne postoji.';
$lang['Cannot_remove_style'] = 'Ne moete izbrisati izabrani stil jer je oznaen kao defaultni za forum.<br />Promijenite defaultni stil foruma i pokuajte ponovo.';
$lang['Style_exists'] = 'Izabrano ime stila ve postoji; vratite se natrag i izaberite drugo ime.';

$lang['Click_return_styleadmin'] = 'Kliknite %sovdje%s za povratak na Administraciju stilova.';

$lang['Theme_settings'] = 'Postavke teme';
$lang['Theme_element'] = 'Elementi teme';
$lang['Simple_name'] = 'Jednostavan naziv';
$lang['Value'] = 'Vrijednost';
$lang['Save_Settings'] = 'Spremite postavke';

$lang['Stylesheet'] = 'CSS Stylesheet';
$lang['Background_image'] = 'Slika pozadine';
$lang['Background_color'] = 'Boja pozadine';
$lang['Theme_name'] = 'Naziv teme';
$lang['Link_color'] = 'Boja linkova';
$lang['Text_color'] = 'Boja teksta';
$lang['VLink_color'] = 'Boja posjeenih linkova';
$lang['ALink_color'] = 'Boja aktivnih linkova';
$lang['HLink_color'] = 'Boja prelazeih linkova';
$lang['Tr_color1'] = 'Boja 1 redova tabela';
$lang['Tr_color2'] = 'Boja 2 redova tabela';
$lang['Tr_color3'] = 'Boja 3 redova tabela';
$lang['Tr_class1'] = 'Class 1 redova tabela';
$lang['Tr_class2'] = 'Class 2 redova tabela';
$lang['Tr_class3'] = 'Class 3 redova tabela';
$lang['Th_color1'] = 'Boja 1 zaglavlja tabela';
$lang['Th_color2'] = 'Boja 2 zaglavlja tabela';
$lang['Th_color3'] = 'Boja 3 zaglavlja tabela';
$lang['Th_class1'] = 'Class 1 zaglavlja tabela';
$lang['Th_class2'] = 'Class 2 zaglavlja tabela';
$lang['Th_class3'] = 'Class 3 zaglavlja tabela';
$lang['Td_color1'] = 'Boja 1 elija tabela';
$lang['Td_color2'] = 'Boja 2 elija tabela';
$lang['Td_color3'] = 'Boja 3 elija tabela';
$lang['Td_class1'] = 'Class 1 elija tabela';
$lang['Td_class2'] = 'Class 2 elija tabela';
$lang['Td_class3'] = 'Class 3 elija tabela';
$lang['fontface1'] = 'Vrsta fonta 1';
$lang['fontface2'] = 'Vrsta fonta 2';
$lang['fontface3'] = 'Vrsta fonta 3';
$lang['fontsize1'] = 'Veliina fonta 1';
$lang['fontsize2'] = 'Veliina fonta 2';
$lang['fontsize3'] = 'Veliina fonta 3';
$lang['fontcolor1'] = 'Boja fonta 1';
$lang['fontcolor2'] = 'Boja fonta 2';
$lang['fontcolor3'] = 'Boja fonta 3';
$lang['span_class1'] = 'Class 1 mjera';
$lang['span_class2'] = 'Class 2 mjera';
$lang['span_class3'] = 'Class 3 mjera';
$lang['img_poll_size'] = 'Veliina anketne slike [px]';
$lang['img_pm_size'] = 'Veliina statusa privatne poruke [px]';

//
// Install Process
//

$lang['Welcome_install'] = 'Dobro doli u phpBB 2 instalaciju';
$lang['Initial_config'] = 'Osnovna konfiguracija';
$lang['DB_config'] = 'Konfiguracija baze';
$lang['Admin_config'] = 'Admin konfiguracija';
$lang['continue_upgrade'] = 'Kada downloadirate konfiguracijsku datoteku, moete kliknuti na gumb \'Nastavite nadogradnju\' kako biste nastavili s nadogradnjom.<br />Priekajte s uploadiranjem konfiguracijske datoteke dok proces nadogradnje ne zavri.';
$lang['upgrade_submit'] = 'Nastavite nadogradnju';

$lang['Installer_Error'] = 'Dolo je do greke prilikom instalacije.';
$lang['Previous_Install'] = 'Detektirana je prethodna instalacija.';
$lang['Install_db_error'] = 'Dolo je do greke prilikom pokuaja nadogradnje baze.';

$lang['Re_install'] = 'Prethodna instalacija je jo uvijek aktivna.<br />Ukoliko elite reinstalirati phpBB 2 kliknite na Da gumb ispod.<br />Obratite panju na to da e to dovesti do unitenja svih postojeih podataka i backupova.<br />Korisniko ime i zaporka administratora/ice, koje ste koristili za loginiranje, bit e ponovo kreirani nakon reinstalacije; ostale postavke nee biti sauvane.<br />Dobro razmislite prije klika na Da.';

$lang['Inst_Step_0'] = 'Hvala Vam to ste izabrali phpBB 2.<br />Da biste zavrili instalaciju, ispunite traene podatke ispod.<br />Baza u koju instalirate bi ve trebala postojati.<br />Ukoliko instalirate u bazu koja koristi ODBC, npr. MS Access, trebali biste prvo kreirati DSN za nju prije nastavka.';

$lang['Start_Install'] = 'Ponite instalaciju';
$lang['Finish_Install'] = 'Zavrite instalaciju';

$lang['Default_lang'] = 'Defaultni jezik foruma';
$lang['DB_Host'] = 'Hostname servera baze / DSN';
$lang['DB_Name'] = 'Ime Vae baze';
$lang['DB_Username'] = 'Korisniko ime baze';
$lang['DB_Password'] = 'Zaporka baze';
$lang['Database'] = 'Vaa baza';
$lang['Install_lang'] = 'Izaberite jezik instalacije';
$lang['dbms'] = 'Tip baze';
$lang['Table_Prefix'] = 'Prefiks za tabele u bazi';
$lang['Admin_Username'] = 'Korisniko ime administratora/ice';
$lang['Admin_Password'] = 'Zaporka administratora/ice';
$lang['Admin_Password_confirm'] = 'Zaporka administratora/ice [potvrdite]';

$lang['Inst_Step_2'] = 'Korisniko ime administratora/ice je kreirano.<br />Ovime je osnovna instalacija zavrena.<br />Otvorit e Vam se stranica na kojoj ete moi izadministrirati Vau novu instalaciju.<br />Provjerite postavke Ope konfiguracije i uredite sve to treba.<br />Hvala Vam to ste izabrali phpBB 2.';

$lang['Unwriteable_config'] = 'Konfiguracijsku datoteku nije mogue editirati.<br /> Kopija konfiguracijske datoteke bit e downloadirana kada kliknete na donji gumb.<br />Uploadajte tu datoteku u istu mapu gdje ste uploadirali i phpBB 2.<br />Tada ete se moi loginirati koristei korisniko ime i zaporku administratora/ice, koje ste unijeli u prethodnoj formi, te otii u AdministratorPanel da provjerite postavke Ope konfiguracije.<br />Hvala Vam to ste izabrali phpBB 2.';
$lang['Download_config'] = 'Downloadirajte konfiguracijsku datoteku';

$lang['ftp_choose'] = 'Izaberite metodu downloada';
$lang['ftp_option'] = '<br />S obzirom da su FTP ekstenzije omoguene u ovoj verziji PHP-a, bit e Vam dana mogunost da prvo putem FTP-a postavite konfiguracijsku datoteku na mjesto.';
$lang['ftp_instructs'] = 'Izabrali ste FTP-iranje datoteke.<br />Unesite informacije ispod kako biste olakali proces.<br />FTP putanja mora biti tono do phpBB 2 instalacije.';
$lang['ftp_info'] = 'Unesite FTP informacije';
$lang['Attempt_ftp'] = 'Pokuajte FTP-irati konfiguracijsku datoteku';
$lang['Send_file'] = 'Poaljite konfiguracijsku datoteku meni - runo u je FTP-irati';
$lang['ftp_path'] = 'FTP putanja do phpBB 2';
$lang['ftp_username'] = 'Vae FTP korisniko ime';
$lang['ftp_password'] = 'Vaa FTP zaporka';
$lang['Transfer_config'] = 'Zaponite transfer';
$lang['NoFTP_config'] = 'Pokuaj FTP-iranja konfiguracijske datoteke nije uspio<br />Downloadirajte konfiguracijsku datoteku i FTP-irajte ju runo.';

$lang['Install'] = 'Instaliranje';
$lang['Upgrade'] = 'Nadogradnja';

$lang['Install_Method'] = 'Izaberite metodu instalacije';

$lang['Install_No_Ext'] = 'PHP konfiguracija Vaeg servera ne podrava tip baze koji ste izabrali.';

$lang['Install_No_PCRE'] = 'phpBB2 zahtijeva <i>Perl-Compatible Regular Expressions Module</i> za PHP koji Vaa PHP konfiguracija, ini se, ne podrava.';

//
// That's all Folks!
//

?>